@@ -3,7 +3,7 @@ BEGIN {
   $Template::Caribou::Tags::HTML::Extended::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Template::Caribou::Tags::HTML::Extended::VERSION = '0.2.0';
+  $Template::Caribou::Tags::HTML::Extended::VERSION = '0.2.1';
 }
 # ABSTRACT: custom HTML tags optimized for DWIMery
 
@@ -150,7 +150,7 @@ Template::Caribou::Tags::HTML::Extended - custom HTML tags optimized for DWIMery
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
@@ -262,7 +262,7 @@ Uses L<Text::MultiMarkdown>.
 
 =head1 AUTHOR
 
-Yanick Champoux
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
