@@ -3,7 +3,7 @@ BEGIN {
   $Template::Caribou::Utils::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Template::Caribou::Utils::VERSION = '0.2.0';
+  $Template::Caribou::Utils::VERSION = '0.2.1';
 }
 
 use strict;
@@ -76,11 +76,11 @@ Template::Caribou::Utils
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 AUTHOR
 
-Yanick Champoux
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
